@@ -58,6 +58,9 @@ class IndexManager:
             del_values = old_values - new_values
             add_values = new_values - old_values
 
+            if add_values:
+                self.check_item(model, add_values)
+
             if del_values:
                 self.delete_item(model, del_values)
 
@@ -65,11 +68,26 @@ class IndexManager:
                 self.add_item(model, add_values)
 
         elif not old_values:
+            self.check_item(model, new_values)
             self.add_item(model, new_values)
 
         elif not new_values:
             self.delete_item(model, old_values)
 
+        self._root_check()
+
+    def check_item(self, model, values):
+        if not self.details.unique or not self.initialized():
+            return
+
+        for value in values:
+            if value in self.table():
+                raise sheraf.exceptions.UniqueIndexException(
+                    "The key '{}' is already present in the index '{}'".format(
+                        value, self.details.key
+                    )
+                )
+
     def _table_del_unique(self, table, key, value):
         del table[key]
 
@@ -79,25 +97,32 @@ class IndexManager:
             del table[key]
 
     def _table_set_unique(self, table, key, value):
-        if key in table:
-            raise sheraf.exceptions.UniqueIndexException(
-                "The key '{}' is already present in the index '{}'".format(
-                    key, self.details.key
-                )
-            )
         table[key] = value
 
     def _table_set_multiple(self, table, key, value):
         index_list = table.setdefault(key, self.index_multiple_default())
         index_list.append(value)
 
+    def _root_check(self):
+        if all((not table for table in self.root().values())):
+            self.delete_root()
+
 
 class SimpleIndexManager(IndexManager):
     persistent = None
 
+    def root(self):
+        return self.persistent
+
+    def delete_root(self):
+        pass
+
     def initialized(self):
         return self.persistent is not None
 
+    def delete(self):
+        del self.persistent[self.details.key]
+
     def table_initialized(self):
         return self.details.key in self.persistent
 
@@ -151,6 +176,9 @@ class MultipleDatabaseIndexManager(IndexManager):
                 raise
             return root.setdefault(self.table_name, self.root_default())
 
+    def delete_root(self, database_name=None):
+        del self.database_root(database_name)[self.table_name]
+
     def delete(self):
         try:
             del self.root()[self.details.key]
