@@ -286,19 +286,21 @@ class QuerySet(object):
             return sum(1 for _ in self)
 
         index_name = list(self.filters.keys())[0]
-        index_value = list(self.filters.values())[0][1]
+        _, filter_value, filter_transformation = list(self.filters.values())[0]
         if index_name not in self.model.indexes:
             return sum(1 for _ in self)
 
         index = self.model.indexes[index_name]
-        if not index.has_item(index_value):
-            return 0
+        if filter_transformation:
+            index_values = index.details.call_search_func(self.model, filter_value)
 
         if index.details.unique:
-            return 1
+            return sum(int(index.has_item(v)) for v in index_values)
 
         else:
-            return len(index.get_item(index_value))
+            return sum(
+                len(index.get_item(v)) for v in index_values if index.has_item(v)
+            )
 
     def copy(self):
         """Copies the :class:`~sheraf.queryset.QuerySet` without consuming it.
@@ -459,9 +461,9 @@ class QuerySet(object):
         The default order is the ascending model ids.
 
         >>> with sheraf.connection(commit=True):
-        ...     peter = Cowboy.create(name="Peter")
-        ...     steven = Cowboy.create(name="Steven")
-        ...     george = Cowboy.create(name="George")
+        ...     peter = Cowboy.create(name="Peter", age=35)
+        ...     steven = Cowboy.create(name="Steven", age=35)
+        ...     george = Cowboy.create(name="George", age=50)
         ...
         >>> with sheraf.connection():
         ...     assert [peter, steven, george] == Cowboy.all()
@@ -474,19 +476,8 @@ class QuerySet(object):
         Several order parameters can be passed, either as arguments of the
         function, or by calling :func:`~sheraf.queryset.QuerySet.order` calls.
 
-        .. warning:: Arguments order is only kept since ``Python 3.6``, so
-            using multiple `order` parameters will result on undefined order
-            for ``Python 3.5-``. If you are using ``Python 3.5-`` and need
-            several :class:`~sheraf.queryset.QuerySet` orders, prefer chaining
-            `order` method calls.
-
-        >>> with sheraf.connection(): # TODO: not skip # doctest: +SKIP
-        ...     assert [george, peter, steven] == Cowboy.all().order(age=sheraf.DESC)
-        ...     assert [george, steven, peter] == Cowboy.all().order(age=sheraf.DESC) \\
-        ...                                                   .order(name=sheraf.ASC)
-        >>> # Only since Python 3.6 # doctest: +SKIP
-        ... with sheraf.connection():
-        ...     assert [george, steven, peter] == Cowboy.all().order(age=sheraf.DESC, name=sheraf.ASC)
+        >>> with sheraf.connection():
+        ...     assert [george, peter, steven] == Cowboy.all().order(age=sheraf.DESC, name=sheraf.ASC)
 
         .. note:: Sorting on indexed attributes is more performant than
             sorting on other attributes. See
